@@ -14,6 +14,7 @@ class AbstractTimelineModel : public QAbstractListModel
 {
     Q_OBJECT
 
+    Q_PROPERTY(bool loading READ loading NOTIFY loadingChanged)
 public:
     enum CustoRoles {
         AvatarRole = Qt::UserRole + 1,
@@ -41,11 +42,18 @@ public:
         UrlRole,
         CardRole,
         TypeRole,
+        ExtraRole, ///< for sub-classes to extend the roles
     };
 
     AbstractTimelineModel(QObject *parent = nullptr);
-    ~AbstractTimelineModel();
+    QHash<int, QByteArray> roleNames() const override;
+
+    bool loading() const;
+
+Q_SIGNALS:
+    void loadingChanged();
 
 protected:
     Account *m_account = nullptr;
+    bool m_loading = true;
 };
