@@ -13,7 +13,7 @@
 
 QString Identity::displayName() const
 {
-    return m_display_name;
+    return !m_display_name.isEmpty() ? m_display_name : m_acct;
 }
 
 QUrl Identity::avatarUrl() const
@@ -39,34 +39,30 @@ void Identity::setRelationship(Relationship *r)
     Q_EMIT relationshipChanged();
 }
 
-Account::Account(const QString &name, const QString &instance_uri, bool ignoreSslErrors, QObject *parent)
+Account::Account(const QString &name, const QString &instance_uri, QNetworkAccessManager *nam, bool ignoreSslErrors, QObject *parent)
     : QObject(parent)
     , m_name(name)
-    , m_qnam(new QNetworkAccessManager(this))
+    , m_ignoreSslErrors(ignoreSslErrors)
+    , m_qnam(nam)
     // default to 500, instances which support more signal it
     , m_maxPostLength(500)
 {
-    if (ignoreSslErrors) {
-        connect(m_qnam, &QNetworkAccessManager::sslErrors, this, [](QNetworkReply * reply, const QList<QSslError> &) {
-            reply->ignoreSslErrors();
-        });
-        m_ignoreSslErrors = true;
-    }
     setInstanceUri(instance_uri);
     m_identity.reparentIdentity(this);
-    auto notificationHandler = new NotificationHandler(this);
+    auto notificationHandler = new NotificationHandler(m_qnam, this);
     connect(this, &Account::notification, notificationHandler, [this, notificationHandler](std::shared_ptr<Notification> notification) {
         notificationHandler->handle(notification, this);
     });
 }
 
-Account::Account(const QSettings &settings, QObject *parent)
+Account::Account(const QSettings &settings, QNetworkAccessManager *nam, QObject *parent)
     : QObject(parent)
-    , m_qnam(new QNetworkAccessManager(this))
+    , m_qnam(nam)
     , m_maxPostLength(500)
 {
+    qDebug() << "XXX";
     m_identity.reparentIdentity(this);
-    auto notificationHandler = new NotificationHandler(this);
+    auto notificationHandler = new NotificationHandler(m_qnam, this);
     connect(this, &Account::notification, notificationHandler, [this, notificationHandler](std::shared_ptr<Notification> notification) {
         notificationHandler->handle(notification, this);
     });
@@ -135,130 +131,87 @@ bool Account::isRegistered() const
 
 void Account::get(const QUrl &url, bool authenticated, std::function<void(QNetworkReply *)> reply_cb)
 {
-    QNetworkRequest request = QNetworkRequest(url);
-
-    if (authenticated && haveToken()) {
-        const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
-        request.setRawHeader("Authorization", bearer);
-    }
-
+    QNetworkRequest request = makeRequest(url, authenticated);
     qCDebug(TOKODON_HTTP) << "GET" << url;
 
     QNetworkReply *reply = m_qnam->get(request);
-
-    if (reply_cb != nullptr) {
-        QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb, &url]() {
-            if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute)) {
-                qCDebug(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << url;
-                return;
-            }
-            reply_cb(reply);
-        });
-    }
+    handleReply(reply, reply_cb);
 }
 
 void Account::post(const QUrl &url, const QJsonDocument &doc, bool authenticated, std::function<void(QNetworkReply *)> reply_cb)
 {
     auto post_data = doc.toJson();
 
-    QNetworkRequest request = QNetworkRequest(url);
+    QNetworkRequest request = makeRequest(url, authenticated);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/json");
-
-    if (authenticated && haveToken()) {
-        const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
-        request.setRawHeader("Authorization", bearer);
-    }
-
     qCDebug(TOKODON_HTTP) << "POST" << url << "[" << post_data << "]";
 
     auto reply = m_qnam->post(request, post_data);
-
-    if (reply_cb != nullptr) {
-        QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb, &url]() {
-            if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute)) {
-                qCDebug(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << url;
-                return;
-            }
-            reply_cb(reply);
-        });
-    }
+    handleReply(reply, reply_cb);
 }
 
 void Account::put(const QUrl &url, const QJsonDocument &doc, bool authenticated, std::function<void(QNetworkReply *)> reply_cb)
 {
     auto post_data = doc.toJson();
 
-    QNetworkRequest request = QNetworkRequest(url);
+    QNetworkRequest request = makeRequest(url, authenticated);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/json");
-
-    if (authenticated && haveToken()) {
-        QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
-        request.setRawHeader("Authorization", bearer);
-    }
-
     qCDebug(TOKODON_HTTP) << "PUT" << url << "[" << post_data << "]";
 
     QNetworkReply *reply = m_qnam->put(request, post_data);
-
-    if (reply_cb != nullptr) {
-        QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb, &url]() {
-            if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute)) {
-                qCDebug(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << url;
-                return;
-            }
-            reply_cb(reply);
-        });
-    }
+    handleReply(reply, reply_cb);
 }
 
 void Account::post(const QUrl &url, const QUrlQuery &formdata, bool authenticated, std::function<void(QNetworkReply *)> reply_cb)
 {
     auto post_data = formdata.toString().toLatin1();
 
-    QNetworkRequest request = QNetworkRequest(url);
+    QNetworkRequest request = makeRequest(url, authenticated);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-
-    if (authenticated && haveToken()) {
-        const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
-        request.setRawHeader("Authorization", bearer);
-    }
-
     qCDebug(TOKODON_HTTP) << "POST" << url << "[" << post_data << "]";
 
     QNetworkReply *reply = m_qnam->post(request, post_data);
-
-    if (reply_cb != nullptr) {
-        QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb, &url]() {
-            if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute)) {
-                qCDebug(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << url;
-                return;
-            }
-            reply_cb(reply);
-        });
-    }
+    handleReply(reply, reply_cb);
 }
 
 void Account::post(const QUrl &url, QHttpMultiPart *message, bool authenticated, std::function<void(QNetworkReply *)> reply_cb)
 {
-    QNetworkRequest request = QNetworkRequest(url);
+    QNetworkRequest request = makeRequest(url, authenticated);
 
     qCDebug(TOKODON_HTTP) << "POST" << url << "(multipart-message)";
 
+    QNetworkReply *reply = m_qnam->post(request, message);
+    message->setParent(reply);
+    handleReply(reply, reply_cb);
+}
+
+QNetworkRequest Account::makeRequest(const QUrl &url, bool authenticated) const
+{
+    QNetworkRequest request(url);
+
     if (authenticated && haveToken()) {
         const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
         request.setRawHeader("Authorization", bearer);
     }
 
-    QNetworkReply *reply = m_qnam->post(request, message);
-    message->setParent(reply);
+    return request;
+}
 
-    if (reply_cb != nullptr) {
-        QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb, &url]() {
+void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply*)> reply_cb) const
+{
+    QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb]() {
+        reply->deleteLater();
+        if (reply_cb) {
             if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute)) {
-                qCDebug(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << url;
+                qCDebug(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
                 return;
             }
             reply_cb(reply);
+        }
+    });
+    if (m_ignoreSslErrors) {
+        connect(reply, &QNetworkReply::sslErrors, this, [reply](const QList<QSslError> &) {
+            reply->ignoreSslErrors();
         });
     }
 }
@@ -443,13 +396,7 @@ void Account::buildFromSettings(const QSettings &settings)
         m_client_secret = settings.value("client_secret").toString();
         m_name = settings.value("name").toString();
         m_instance_uri = settings.value("instance_uri").toString();
-
-        if (settings.value("ignoreSslErrors", false).toBool()) {
-            connect(m_qnam, &QNetworkAccessManager::sslErrors, this, [](QNetworkReply * reply, const QList<QSslError> &) {
-                reply->ignoreSslErrors();
-            });
-            m_ignoreSslErrors = true;
-        }
+        m_ignoreSslErrors = settings.value("ignoreSslErrors", false).toBool();
         validateToken();
     }
 }
@@ -567,64 +514,6 @@ void Account::fetchTimeline(const QString &original_name, const QString &from_id
     });
 }
 
-void Account::fetchThread(const QString &post_id, std::function<void(QList<std::shared_ptr<Post>>)> final_cb)
-{
-    auto status_url = apiUrl(QString("/api/v1/statuses/%1").arg(post_id));
-    auto context_url = apiUrl(QString("/api/v1/statuses/%1/context").arg(post_id));
-    auto thread = std::make_shared<QList<std::shared_ptr<Post>>>();
-
-    auto on_fetch_context = [=](QNetworkReply *reply) {
-        auto data = reply->readAll();
-        auto doc = QJsonDocument::fromJson(data);
-        auto obj = doc.object();
-
-        if (!doc.isObject())
-            return;
-
-        const auto ancestors = obj["ancestors"].toArray();
-
-        for (const auto &anc : ancestors) {
-            if (!anc.isObject())
-                continue;
-
-            auto anc_obj = anc.toObject();
-            auto p = std::make_shared<Post>(this, anc_obj);
-
-            thread->push_front(p);
-        }
-
-        const auto descendents = obj["descendants"].toArray();
-
-        for (const auto &desc : descendents) {
-            if (!desc.isObject())
-                continue;
-
-            auto desc_obj = desc.toObject();
-            auto p = std::make_shared<Post>(this, desc_obj);
-
-            thread->push_back(p);
-        }
-
-        final_cb(*thread);
-    };
-
-    auto on_fetch_status = [=](QNetworkReply *reply) {
-        auto data = reply->readAll();
-        auto doc = QJsonDocument::fromJson(data);
-        auto obj = doc.object();
-
-        if (!doc.isObject())
-            return;
-
-        auto p = std::make_shared<Post>(this, obj);
-        thread->push_front(p);
-
-        get(context_url, true, on_fetch_context);
-    };
-
-    get(status_url, true, on_fetch_status);
-}
-
 void Account::postStatus(Post *p)
 {
     QUrl post_status_url = apiUrl("/api/v1/statuses");
@@ -686,16 +575,19 @@ static Account::AllowedContentType parseVersion(const QString &instanceVer)
     using ContentType = Account::AllowedContentType;
 
     unsigned int result = ContentType::PlainText;
-    if (instanceVer.contains("glitch"))
+    if (instanceVer.contains("glitch")) {
         result |= ContentType::Markdown | ContentType::Html;
+    }
 
     return static_cast<ContentType>(result);
 }
 
-static QMap<QString, Account::AllowedContentType> str_to_content_type = {{"text/plain", Account::AllowedContentType::PlainText},
-                                                                         {"text/bbcode", Account::AllowedContentType::BBCode},
-                                                                         {"text/html", Account::AllowedContentType::Html},
-                                                                         {"text/markdown", Account::AllowedContentType::Markdown}};
+static QMap<QString, Account::AllowedContentType> stringToContentType = {
+    {"text/plain", Account::AllowedContentType::PlainText},
+    {"text/bbcode", Account::AllowedContentType::BBCode},
+    {"text/html", Account::AllowedContentType::Html},
+    {"text/markdown", Account::AllowedContentType::Markdown},
+};
 
 static Account::AllowedContentType parse_pleroma_info(const QJsonDocument &doc)
 {
@@ -713,10 +605,10 @@ static Account::AllowedContentType parse_pleroma_info(const QJsonDocument &doc)
         for (auto c : formats) {
             auto fmt = c.toString();
 
-            if (!str_to_content_type.contains(fmt))
+            if (!stringToContentType.contains(fmt))
                 continue;
 
-            result |= (unsigned int)str_to_content_type[fmt];
+            result |= (unsigned int)stringToContentType[fmt];
         }
     }
 
