@@ -63,7 +63,6 @@ public:
     void fetchAvatar(const QUrl &avatar_url);
     void reparentIdentity(Account *parent);
 
-    QNetworkAccessManager *m_qnam;
     Account *m_parent;
 
     Relationship *relationship() const;
@@ -92,8 +91,8 @@ class Account : public QObject
     Q_PROPERTY(Identity *identity READ identityObj CONSTANT)
 
 public:
-    explicit Account(const QString &username, const QString &instance_uri, bool ignoreSslErrors = false, QObject *parent = nullptr);
-    explicit Account(const QSettings &settings, QObject *parent = nullptr);
+    explicit Account(const QString &username, const QString &instance_uri, QNetworkAccessManager *nam, bool ignoreSslErrors = false, QObject *parent = nullptr);
+    explicit Account(const QSettings &settings, QNetworkAccessManager *nam, QObject *parent = nullptr);
     ~Account();
 
     // API stuff (registering)
@@ -183,9 +182,6 @@ public:
     void upload(Post *p, QFile *file, QString filename);
     void updateAttachment(Attachment *a);
 
-    /// Thread fetching
-    void fetchThread(const QString &postId, std::function<void(QList<std::shared_ptr<Post>>)> final_cb);
-
     /// Fetch account timeline
     void fetchAccount(qint64 id, bool excludeReplies, const QString &timelineName, const QString &from_id = QString());
 
@@ -286,4 +282,8 @@ private:
     // updates and notifications
     void handleUpdate(const QJsonDocument &doc, const QString &target);
     void handleNotification(const QJsonDocument &doc);
+
+    // common parts for all HTTP request
+    QNetworkRequest makeRequest(const QUrl &url, bool authenticated) const;
+    void handleReply(QNetworkReply *reply, std::function<void(QNetworkReply *)> reply_cb) const;
 };
