@@ -3,10 +3,12 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "accountmanager.h"
+#include "networkaccessmanagerfactory.h"
 
 AccountManager::AccountManager(QObject *parent)
     : QAbstractListModel(parent)
     , m_selected_account(nullptr)
+    , m_qnam(NetworkAccessManagerFactory().create(this))
 {
     QSettings settings;
     loadFromSettings(settings);
@@ -18,7 +20,7 @@ AccountManager::~AccountManager()
     QSettings settings;
     writeToSettings(settings);
 
-    for (auto a : m_accounts) {
+    for (auto a : std::as_const(m_accounts)) {
         delete a;
     }
 
@@ -45,6 +47,7 @@ QVariant AccountManager::data(const QModelIndex &index, int role) const
 
 int AccountManager::rowCount(const QModelIndex &index) const
 {
+    Q_UNUSED(index)
     return m_accounts.size();
 }
 
@@ -65,7 +68,7 @@ AccountManager &AccountManager::instance()
 
 Account *AccountManager::createNewAccount(const QString &username, const QString &instanceUri, bool ignoreSslErrors)
 {
-    return new Account(username, instanceUri, ignoreSslErrors, this);
+    return new Account(username, instanceUri, m_qnam, ignoreSslErrors, this);
 }
 
 bool AccountManager::hasAccounts() const
@@ -173,7 +176,7 @@ void AccountManager::loadFromSettings(QSettings &settings)
     for (const auto &child : childGroups) {
         settings.beginGroup(child);
 
-        auto account = new Account(settings);
+        auto account = new Account(settings, m_qnam);
         if (account->haveToken()) {
             addAccount(account);
             qDebug() << "Loaded from settings:" << account;
