@@ -35,6 +35,7 @@
 #include "attachmenteditormodel.h"
 #include "clipboard.h"
 #include "config.h"
+#include "networkaccessmanagerfactory.h"
 #include "notificationmodel.h"
 #include "post.h"
 #include "timelinemodel.h"
@@ -72,6 +73,7 @@ int main(int argc, char *argv[])
     font.setPointSize(10);
     app.setFont(font);
 #endif
+    KLocalizedString::setApplicationDomain("tokodon");
 
     QCoreApplication::setOrganizationName("KDE");
 
@@ -81,8 +83,10 @@ int main(int argc, char *argv[])
                      i18n("Mastodon client"),
                      KAboutLicense::GPL_V3,
                      i18n("© 2021 Carl Schwan, 2021 KDE Community"));
-    about.addAuthor(i18n("Carl Schwan"), QString(), QStringLiteral("carl@carlschwan.eu"));
+    about.addAuthor(i18n("Carl Schwan"), i18n("Maintainer"), QStringLiteral("carl@carlschwan.eu"));
+    about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     about.setOrganizationDomain("kde.org");
+    about.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=tokodon");
 
     KAboutData::setApplicationData(about);
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.tokodon")));
@@ -96,12 +100,10 @@ int main(int argc, char *argv[])
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "AccountManager", &AccountManager::instance());
     qmlRegisterType<TimelineModel>("org.kde.kmasto", 1, 0, "TimelineModel");
     qmlRegisterType<NotificationModel>("org.kde.kmasto", 1, 0, "NotificationModel");
-    qmlRegisterSingletonType<Clipboard>("org.kde.kmasto", 1, 0, "Clipboard", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
-        Q_UNUSED(engine)
-        Q_UNUSED(scriptEngine)
-        return new Clipboard;
-    });
-    qmlRegisterType<AttachmentEditorModel>("org.kde.kmasto", 1, 0, "AttachmentEditorModel");
+    qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Clipboard", new Clipboard);
+    qmlRegisterSingletonType("org.kde.kmasto", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+        return engine->toScriptValue(KAboutData::applicationData());
+    });    qmlRegisterType<AttachmentEditorModel>("org.kde.kmasto", 1, 0, "AttachmentEditorModel");
     qRegisterMetaType<Account *>("Account*");
     qRegisterMetaType<Identity *>("Identity*");
     qRegisterMetaType<Relationship *>("Relationship*");
@@ -113,6 +115,9 @@ int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("kmasto");
     QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
 
+    NetworkAccessManagerFactory namFactory;
+    engine.setNetworkAccessManagerFactory(&namFactory);
+
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Client for the decentralized social network: mastodon"));
 
