@@ -75,8 +75,8 @@ void NotificationModel::fillTimeline(const QUrl &next)
     } else {
         uri = next;
     }
-    QUrlQuery urlQuery;
-    for (const auto &excludeType : m_excludeTypes) {
+    QUrlQuery urlQuery(uri);
+    for (const auto &excludeType : std::as_const(m_excludeTypes)) {
         urlQuery.addQueryItem("exclude_types[]", excludeType);
     }
     uri.setQuery(urlQuery);
@@ -85,8 +85,13 @@ void NotificationModel::fillTimeline(const QUrl &next)
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
+        if (m_loading) {
+            m_loading = false;
+            Q_EMIT loadingChanged();
+        }
+
         if (!doc.isArray()) {
-            qDebug() << data;
+            m_account->errorOccured(i18n("Error occurred when fetching the latest notification."));
             return;
         }
         static QRegularExpression re("<(.*)>; rel=\"next\"");
@@ -95,7 +100,8 @@ void NotificationModel::fillTimeline(const QUrl &next)
         m_next = QUrl::fromUserInput(match.captured(1));
 
         QList<std::shared_ptr<Notification>> notifications;
-        for (const auto &value : doc.array()) {
+        const auto values = doc.array();
+        for (const auto &value : values) {
             QJsonObject obj = value.toObject();
 
             auto notification = std::make_shared<Notification>(m_account, obj);
@@ -109,7 +115,7 @@ void NotificationModel::fetchMore(const QModelIndex &parent)
 {
     Q_UNUSED(parent);
 
-    if (m_notifications.size() < 1) {
+    if (m_notifications.isEmpty() || !m_next.isValid()) {
         return;
     }
 
@@ -153,32 +159,9 @@ std::shared_ptr<Notification> NotificationModel::internalData(const QModelIndex
 
 QHash<int, QByteArray> NotificationModel::roleNames() const
 {
-    return {
-        {Qt::DisplayRole, QByteArrayLiteral("display")},
-        {AvatarRole, QByteArrayLiteral("avatar")},
-        {AuthorDisplayNameRole, QByteArrayLiteral("authorDisplayName")},
-        {PinnedRole, QByteArrayLiteral("pinned")},
-        {AuthorIdRole, QByteArrayLiteral("authorId")},
-        {PublishedAtRole, QByteArrayLiteral("publishedAt")},
-        {RelativeTimeRole, QByteArrayLiteral("relativeTime")},
-        {SensitiveRole, QByteArrayLiteral("sensitive")},
-        {SpoilerTextRole, QByteArrayLiteral("spoilerText")},
-        {RebloggedRole, QByteArrayLiteral("reblogged")},
-        {WasRebloggedRole, QByteArrayLiteral("wasReblogged")},
-        {RebloggedDisplayNameRole, QByteArrayLiteral("rebloggedDisplayName")},
-        {RebloggedIdRole, QByteArrayLiteral("rebloggedId")},
-        {AttachmentsRole, QByteArrayLiteral("attachments")},
-        {ReblogsCountRole, QByteArrayLiteral("reblogsCount")},
-        {RepliesCountRole, QByteArrayLiteral("repliesCount")},
-        {FavoritedRole, QByteArrayLiteral("favorite")},
-        {FavoritesCountRole, QByteArrayLiteral("favoritesCount")},
-        {UrlRole, QByteArrayLiteral("url")},
-        {ThreadModelRole, QByteArrayLiteral("threadModel")},
-        {AccountModelRole, QByteArrayLiteral("accountModel")},
-        {TypeRole, QByteArrayLiteral("type")},
-        {CardRole, QByteArrayLiteral("card")},
-        {ActorDisplayNameRole, QByteArrayLiteral("actorDisplayName")},
-    };
+    auto roles = AbstractTimelineModel::roleNames();
+    roles.insert(ActorDisplayNameRole, QByteArrayLiteral("actorDisplayName"));
+    return roles;
 }
 
 QVariant NotificationModel::data(const QModelIndex &index, int role) const
