@@ -13,7 +13,6 @@ TimelineModel::TimelineModel(QObject *parent)
     : AbstractTimelineModel(parent)
     , m_last_fetch(time(nullptr))
 {
-    connect(m_manager, &AccountManager::accountSelected, this, &TimelineModel::nameChanged);
 }
 
 void TimelineModel::setName(const QString &timelineName)
@@ -139,6 +138,9 @@ void TimelineModel::fetchedTimeline(Account *account, const QString &original_na
     m_fetching = false;
     Q_EMIT fetchingChanged();
 
+    m_loading = false;
+    Q_EMIT loadingChanged();
+
     // make sure the timeline update is for us
     if (account != m_account || original_name != m_timelineName) {
         return;
@@ -148,9 +150,6 @@ void TimelineModel::fetchedTimeline(Account *account, const QString &original_na
         return;
     }
 
-    int row = 0;
-    int last = 0;
-
     if (!m_timeline.isEmpty()) {
         const auto post_old = m_timeline.first();
         const auto post_new = posts.first();
@@ -158,23 +157,22 @@ void TimelineModel::fetchedTimeline(Account *account, const QString &original_na
         qDebug() << "fetchedTimeline"
                  << "post_old->m_post_id" << post_old->m_post_id << "post_new->m_post_id" << post_new->m_post_id;
         if (post_old->m_post_id > post_new->m_post_id) {
-            row = m_timeline.size();
-            last = row + posts.size() - 1;
+            const int row = m_timeline.size();
+            const int last = row + posts.size() - 1;
+            beginInsertRows(QModelIndex(), row, last);
             m_timeline += posts;
+            endInsertRows();
         } else {
-            row = 0;
-            last = posts.size();
+            beginInsertRows(QModelIndex(), 0, posts.size() - 1);
             m_timeline = posts + m_timeline;
+            endInsertRows();
         }
     } else {
-        row = 0;
-        last = posts.size() - 1;
+        beginInsertRows(QModelIndex(), 0, posts.size() - 1);
         m_timeline = posts;
+        endInsertRows();
     }
 
-    beginInsertRows(QModelIndex(), row, last);
-    endInsertRows();
-
     m_last_fetch = time(nullptr);
 }
 
@@ -192,37 +190,6 @@ std::shared_ptr<Post> TimelineModel::internalData(const QModelIndex &index) cons
     return m_timeline[row];
 }
 
-QHash<int, QByteArray> TimelineModel::roleNames() const
-{
-    return {
-        {Qt::DisplayRole, QByteArrayLiteral("display")},
-        {AvatarRole, QByteArrayLiteral("avatar")},
-        {AuthorDisplayNameRole, QByteArrayLiteral("authorDisplayName")},
-        {PinnedRole, QByteArrayLiteral("pinned")},
-        {IdRole, QByteArrayLiteral("id")},
-        {AuthorIdRole, QByteArrayLiteral("authorId")},
-        {PublishedAtRole, QByteArrayLiteral("publishedAt")},
-        {MentionsRole, QByteArrayLiteral("mentions")},
-        {RelativeTimeRole, QByteArrayLiteral("relativeTime")},
-        {SensitiveRole, QByteArrayLiteral("sensitive")},
-        {SpoilerTextRole, QByteArrayLiteral("spoilerText")},
-        {RebloggedRole, QByteArrayLiteral("reblogged")},
-        {WasRebloggedRole, QByteArrayLiteral("wasReblogged")},
-        {RebloggedDisplayNameRole, QByteArrayLiteral("rebloggedDisplayName")},
-        {RebloggedIdRole, QByteArrayLiteral("rebloggedId")},
-        {AttachmentsRole, QByteArrayLiteral("attachments")},
-        {ReblogsCountRole, QByteArrayLiteral("reblogsCount")},
-        {RepliesCountRole, QByteArrayLiteral("repliesCount")},
-        {FavoritedRole, QByteArrayLiteral("favorite")},
-        {FavoritesCountRole, QByteArrayLiteral("favoritesCount")},
-        {UrlRole, QByteArrayLiteral("url")},
-        {ThreadModelRole, QByteArrayLiteral("threadModel")},
-        {AccountModelRole, QByteArrayLiteral("accountModel")},
-        {CardRole, QByteArrayLiteral("card")},
-        {TypeRole, QByteArrayLiteral("type")},
-    };
-}
-
 QVariant TimelineModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
